'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.setTokens = setTokens;
exports.getExpiresAt = getExpiresAt;
exports.getRefreshToken = getRefreshToken;
exports.getAccessToken = getAccessToken;
exports.refreshToken = refreshToken;
exports.login = login;
exports.isLoggedIn = isLoggedIn;
exports.isTokenFresh = isTokenFresh;
exports.preflightTokenCheck = preflightTokenCheck;
exports.logout = logout;

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _jwtDecode = require('jwt-decode');

var _jwtDecode2 = _interopRequireDefault(_jwtDecode);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var xAuthToken = 'rhR7SC8hbTflgiqAq7uKJVogMkIySGRQ';
var syncIdentifier = 'com.invisionlabs.sync';

var authorizationFailureError = 'authorizationFailureError';

function setAccessToken(panel, accessToken) {
  var decodedToken = (0, _jwtDecode2.default)(accessToken);
  var expiresAt = decodedToken.exp;

  panel.set('access_token', accessToken, syncIdentifier);
  panel.set('expires_at', expiresAt, syncIdentifier);
};

function newRequest(params) {
  params.headers = params && params.headers || {};
  params.headers = _extends({}, window.panel.api.getHeaders(), params.headers);

  // remove tokens from header if it is a new authentication
  if (params.headers['Authorization'] || params.headers['X-Access-Token']) {
    delete params.headers['InVision-JWT'];
    delete params.headers['X-Invision-Access-Token'];
  }

  return params;
}

function setRefreshToken(panel, refreshToken) {
  panel.set('refresh_token', refreshToken, syncIdentifier);
}

function setTokens(panel, accessToken, refreshToken) {
  setAccessToken(panel, accessToken);
  setRefreshToken(panel, refreshToken);
}

function unsetTokens(panel) {
  panel.set('access_token', undefined, syncIdentifier);
  panel.set('refresh_token', undefined, syncIdentifier);
  panel.set('refreshed_at', undefined, syncIdentifier);
  panel.set('expires_at', undefined, syncIdentifier);
}

function getExpiresAt(panel) {
  return panel.get('expires_at', undefined, syncIdentifier);
}

function getRefreshToken(panel) {
  return panel.get('refresh_token', undefined, syncIdentifier);
}

function getAccessToken(panel) {
  return panel.get('access_token', undefined, syncIdentifier);
}

function getDomain(panel) {
  return panel.get('domain', undefined, syncIdentifier);
}

function getBaseDomain(panel) {
  return panel.get('baseDomain', undefined, syncIdentifier);
}

/*
  * In order to ensure there are not breaking changes to V6,
  * we need the following function
  */
function isApiV7(panel) {
  if (panel.api.isApiV7 && typeof panel.api.isApiV7 === 'function') {
    return panel.api.isApiV7(panel);
  }

  return false;
};

function getAuthApiUrl(panel) {
  var domain = getDomain(panel);

  if (isApiV7(panel)) {
    if (!domain) {
      domain = 'login';
    }

    return panel.api.getV7Host(domain) + panel.api.getBaseLoginApiV7();
  }

  return 'https://auth-api.' + getBaseDomain(panel) + '/api/v1';
}

function getLoginPath(panel) {
  return isApiV7(panel) ? '/login?nocookie' : '/login';
}

function refreshToken(panel, callback) {
  var body = {
    refreshtoken: getRefreshToken(panel)
  };

  var req = newRequest({
    url: getAuthApiUrl(panel) + '/refresh',
    body: body,
    json: true
  });

  _request2.default.post(req, function (err, httpResponse, body) {
    if (err) {
      callback(err);
      return;
    }

    if (!body) {
      callback({ error: 'There was a problem while signing you in. Please try again.' });
      return;
    }

    if (body && body.status === 'error') {
      callback({ error: body.message });
      return;
    }

    setAccessToken(panel, body['JWT']);
    callback();
  });
};

function login(panel, email, password, callback) {
  var req = newRequest({
    url: getAuthApiUrl(panel) + getLoginPath(panel),
    headers: { 'X-Access-Token': xAuthToken },
    body: {
      email: email,
      password: password,
      device: 'sync-photoshop',
      refreshable: true
    },
    json: true
  });

  _request2.default.post(req, function (err, httpResponse, body) {
    if (err) {
      callback({ error: err });
      return;
    }

    if (!body) {
      callback({ error: 'There was a problem while signing you in. Please try again.' });
      return;
    }

    if (body && body.status === 'error') {
      callback({ error: body.message });
      return;
    }

    setTokens(panel, body['JWT'], body['refreshtoken']);
    callback({ ok: true, email: email });
  });
};

function invalidateTokens(panel) {
  var req = newRequest({
    url: getAuthApiUrl(panel) + '/logout',
    headers: { Authorization: 'Bearer ' + getAccessToken(panel) },
    body: { devices: ['sync-photoshop'] },
    json: true
  });

  _request2.default.post(req);
}

function isLoggedIn(panel) {
  if (panel == null) {
    panel = window.panel;
  }
  return getAccessToken(panel) != null;
};

function isTokenFresh(panel) {
  if (panel == null) {
    panel = window.panel;
  }

  var expiresAt = getExpiresAt(panel) || 0;
  var nowInSec = Date.now() / 1000;

  return expiresAt - nowInSec > 20;
}

function preflightTokenCheck(panel, callback) {
  if (panel == null) {
    panel = window.panel;
  }

  if (isTokenFresh()) {
    callback();
  } else {
    refreshToken(panel, function (error) {
      if (error != null) {
        callback(authorizationFailureError);
        return;
      }

      callback();
    });
  }
}

function logout(panel) {
  preflightTokenCheck(panel, function (err) {
    if (err == null) {
      invalidateTokens(panel);
    }

    unsetTokens(panel);
  });
}